package com.ruoyi.mall.service;

import java.util.List;
import com.ruoyi.mall.domain.MallMemberIntegral;

/**
 * 用户积分记录Service接口
 * 
 * @author ruoyi
 * @date 2024-06-21
 */
public interface IMallMemberIntegralService 
{
    /**
     * 查询用户积分记录
     * 
     * @param integralId 用户积分记录主键
     * @return 用户积分记录
     */
    public MallMemberIntegral selectMallMemberIntegralByIntegralId(Long integralId);

    /**
     * 查询用户积分记录列表
     * 
     * @param mallMemberIntegral 用户积分记录
     * @return 用户积分记录集合
     */
    public List<MallMemberIntegral> selectMallMemberIntegralList(MallMemberIntegral mallMemberIntegral);

    /**
     * 新增用户积分记录
     * 
     * @param mallMemberIntegral 用户积分记录
     * @return 结果
     */
    public int insertMallMemberIntegral(MallMemberIntegral mallMemberIntegral);

    /**
     * 修改用户积分记录
     * 
     * @param mallMemberIntegral 用户积分记录
     * @return 结果
     */
    public int updateMallMemberIntegral(MallMemberIntegral mallMemberIntegral);

    /**
     * 批量删除用户积分记录
     * 
     * @param integralIds 需要删除的用户积分记录主键集合
     * @return 结果
     */
    public int deleteMallMemberIntegralByIntegralIds(Long[] integralIds);

    /**
     * 删除用户积分记录信息
     * 
     * @param integralId 用户积分记录主键
     * @return 结果
     */
    public int deleteMallMemberIntegralByIntegralId(Long integralId);
}
